@@ -18,7 +18,6 @@ class EntityPermissionsReport:
         self._csv_full_path = None
         self._csv_file = None
         self._csv_writer = None
-        self._lookup_cache = {}
 
     CSV_HEADERS = ['entity_type',
                    'entity_id',
@@ -94,16 +93,16 @@ class EntityPermissionsReport:
                         resource.get('accessType').sort()
 
                     for resource in resource_accesses:
-                        user_or_team = self._get_user_or_team(resource.get('principalId'))
+                        user_or_team = SynapseProxy.WithCache.get_user_or_team(resource.get('principalId'))
                         permission_level = SynapseProxy.Permissions.name(resource.get('accessType'))
                         self._display_principal(entity, entity_type, permission_level, user_or_team)
 
                         if isinstance(user_or_team, syn.Team):
-                            members = self._get_team_members(user_or_team)
+                            members = SynapseProxy.WithCache.get_team_members(user_or_team.id)
                             for record in members:
                                 member = record.get('member')
                                 user_id = member.get('ownerId')
-                                user = self._get_user(user_id)
+                                user = SynapseProxy.WithCache.get_user(user_id)
                                 self._display_principal(entity,
                                                         entity_type,
                                                         permission_level,
@@ -183,34 +182,3 @@ class EntityPermissionsReport:
                 'emails': emails,
                 'permission_level': permission_level
             })
-
-    def _get_user(self, id):
-        cache_key = 'USER_{0}'.format(id)
-        try:
-            if cache_key not in self._lookup_cache:
-                self._lookup_cache[cache_key] = SynapseProxy.client().getUserProfile(id, refresh=True)
-        except syn.core.exceptions.SynapseHTTPError:
-            self._lookup_cache[cache_key] = None
-        return self._lookup_cache[cache_key]
-
-    def _get_team(self, id):
-        cache_key = 'TEAM_{0}'.format(id)
-        try:
-            if cache_key not in self._lookup_cache:
-                self._lookup_cache[cache_key] = SynapseProxy.client().getTeam(id)
-        except syn.core.exceptions.SynapseHTTPError:
-            self._lookup_cache[cache_key] = None
-        return self._lookup_cache[cache_key]
-
-    def _get_team_members(self, team):
-        cache_key = 'TEAM_MEMBERS_{0}'.format(team.id)
-        try:
-            if cache_key not in self._lookup_cache:
-                self._lookup_cache[cache_key] = list(SynapseProxy.client().getTeamMembers(team))
-        except syn.core.exceptions.SynapseHTTPError:
-            self._lookup_cache[cache_key] = None
-        return self._lookup_cache[cache_key]
-
-    def _get_user_or_team(self, id):
-        # NOTE: User and Team IDs do NOT overlap in Synapse.
-        return self._get_user(id) or self._get_team(id)
